@@ -252,42 +252,42 @@ DNFOptim.dynamicsSVM <- function(dynamics, data, N = 50, K = 20, R = 1, grids =
     }
     
     if(dynamics$delta < 0 |  dynamics$rho <= -1 |  dynamics$rho >= 1 |  dynamics$nu < 0){
-      LL <- -9999999999999999999
+     LL <- -1e+308
       return(-LL)
     }
     if(any(dynamics$model == c("DuffiePanSingleton", "Bates", "Heston"))){
       if(theta <= 0){ 
-        LL <- -9999999999999999999
+       LL <- -1e+308
         return(-LL)
       }
       if(kappa <= 0){ 
-        LL <- -9999999999999999999
+       LL <- -1e+308
         return(-LL)
       }
       if(sigma <= 0){ 
-        LL <- -9999999999999999999
+       LL <- -1e+308
         return(-LL)
       }
       if(dynamics$model != "Heston"){
         if(omega <= 0){
-          LL <- -9999999999999999999
+         LL <- -1e+308
           return(-LL)
         }
       } 
     }
     if(any(dynamics$model == c("PittMalikDoucet", "TaylorWithLeverage", "Taylor"))){
       if(sigma <= 0){ 
-        LL <- -9999999999999999999
+       LL <- -1e+308
         return(-LL)
       }
       if(dynamics$model == "PittMalikDoucet"){
         if(p <= 0 || p >= 1){
-          LL <- -9999999999999999999
+         LL <- -1e+308
           return(-LL)
         }
       }
       if(phi <= 0 || phi >= 1){
-        LL <- -9999999999999999999
+       LL <- -1e+308
         return(-LL)
       }
     }
@@ -299,7 +299,7 @@ DNFOptim.dynamicsSVM <- function(dynamics, data, N = 50, K = 20, R = 1, grids =
     LL <- DNF(data = data, N = N, K = K, R = R, dynamics = dynamics, grids = grids)$log_likelihood
     if (LL == Inf | LL == -Inf) {
       # There can be issues with unusual parameter combinations
-      LL <- -9999999999999999999 # Need finite results
+     LL <- -1e+308 # Need finite results
     }
     return(-LL)
   }
